@@ -16,6 +16,7 @@
 
 #include <kapp.h>
 
+#include <qdatetime.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qwidget.h>
@@ -41,9 +42,10 @@ class KPopup : public QWidget
          QLabel *L_PopupText;
          QLabel *L_Label_Sender;
          QLabel *L_Sender;
-         QLabel *L_Label_Time;
-         QLabel *L_Time;
+         QLabel *L_Label_DateTime;
+         QLabel *L_DateTime;
+         QDate *Date;
+         QTime *Time;
          char *Sender;
          char *Filename;
-         char *Time;
 };
