@@ -16,7 +16,7 @@
 
 #include <ctype.h>
 #include <malloc.h>
-#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
 
 #include <qdialog.h>
@@ -35,21 +35,21 @@ make_Popup::make_Popup(QWidget *parent, const char *name) : QDialog(parent, name
 
  ReadHostName();
 
- B_Ok = new QPushButton("Ok", this);
+ B_Ok = new QPushButton(i18n("Ok"), this);
  B_Ok -> setGeometry(25, 165, 60, 25);
  connect(B_Ok, SIGNAL(clicked()), SLOT(SendPopup()));
 
- B_Cancel = new QPushButton("Cancel", this );
- B_Cancel -> setGeometry(195, 165, 60, 25);
+ B_Cancel = new QPushButton(i18n("Cancel"), this );
+ B_Cancel -> setGeometry(185, 165, 70, 25);
  connect(B_Cancel, SIGNAL(clicked()), SLOT(reject()));
 
- L_Receiver = new QLabel("To:", this);
+ L_Receiver = new QLabel(i18n("To:"), this);
  L_Receiver -> setGeometry(20, 9, 30, 20);
 
  CB_Receiver = new QComboBox(TRUE, this, "read-write combo");
  CB_Receiver -> setGeometry(55, 8, 205, 22);
 
- L_Text = new QLabel("Text:", this);
+ L_Text = new QLabel(i18n("Text:"), this);
  L_Text -> setGeometry(20, 33, 98, 20);
 
  MLE_Text = new QMultiLineEdit(this);
@@ -68,35 +68,37 @@ make_Popup::~make_Popup()
 
 void make_Popup::SendPopup()
 {
- FILE *Datei;
- char *befehlszeile;
- int count=0;
+ FILE *sendprocess;
+ char *commandline;
+ int linecount = 0;
 
- befehlszeile = (char *) malloc (182 * (sizeof(char)));
- Datei = fopen("/tmp/new.kpopup", "w+");
+ commandline = (char *) malloc (182 * (sizeof(char)));
 
- while(count < MLE_Text -> numLines())
-  {
-   fprintf(Datei,"%s\n", MLE_Text -> textLine(count));
-   count++;
-  }
- fclose(Datei);
- sprintf(befehlszeile, "cat /tmp/new.kpopup | %s/smbclient -M %s -N -U %s", SMBPATH , CB_Receiver -> currentText(), hostname);
- if(system(befehlszeile) == 0)
+ sprintf(commandline, "%s/smbclient -M %s -N -U %s > /dev/null", SMBPATH, CB_Receiver -> currentText(), hostname);
+
+ if((sendprocess = popen(commandline, "w")) != 0)
    {
-    QMessageBox *Super;
-    Super = new QMessageBox();
-    Super -> information(this, "Success", "Popup sent!");
-    reject();
+    while(linecount < MLE_Text -> numLines())
+     {
+      fprintf(sendprocess, "%s\n", MLE_Text -> textLine(linecount));
+      linecount++;
+     }
+   if(pclose(sendprocess) == 0)
+     {
+      QMessageBox *Super;
+      Super = new QMessageBox();
+      Super -> information(this, i18n("Success"), i18n("Popup sent!"));
+      reject();
+     }
+    else
+     {
+      QMessageBox *Fehler;
+      Fehler = new QMessageBox();
+      Fehler -> information(this, i18n("Error"), i18n("Popup not sent!"));
+     }
    }
-  else
-   {
-    QMessageBox *Fehler;
-    Fehler = new QMessageBox();
-    Fehler -> information(this, "Error", "Popup not sent!");
-   }
- system("rm -f /tmp/new.kpopup");
- free(befehlszeile);
+
+ free(commandline);
 }
 
 
@@ -147,5 +149,3 @@ void make_Popup::ReadHostName()
  gethostname(hostname, 30);
  for(int i = 0; i <= 29; i++) hostname[i] = toupper(hostname[i]);
 }
-
-
